from aiia import AIIAConfig


class UpsamplerConfig(AIIAConfig):
    def __init__(
        self,
        upsample_scale: int = 2,
        upsample_mode: str = 'bilinear',
        upsample_align_corners: bool = False,
        layers=None,
        **kwargs
    ):
        # Initialize base configuration.
        super().__init__(**kwargs)
        self.layers = layers if layers is not None else []
        
        # Upsampler-specific parameters.
        self.upsample_scale = upsample_scale
        self.upsample_mode = upsample_mode
        self.upsample_align_corners = upsample_align_corners
        
        # Automatically add the upsample layer details.
        self.add_upsample_layer()

    def add_upsample_layer(self):
        upsample_layer = {
            'name': 'Upsample',
            'type': 'nn.Upsample',
            'scale_factor': self.upsample_scale,
            'mode': self.upsample_mode,
            'align_corners': self.upsample_align_corners
        }
        # Add the upsample layer only if not already present.
        if not any(layer.get('name') == 'Upsample' for layer in self.layers):
            self.layers.append(upsample_layer)

